@@ -31,6 +31,8 @@
 #include <gtkmm/entry.h>
 #include <gtkmm/filechooserbutton.h>
 #include <gtkmm/stock.h>
+#include <gtkmm/treeview.h>
+#include <gtkmm/liststore.h>
 #include "nmv-exception.h"
 #include "nmv-run-program-dialog.h"
 #include "nmv-env.h"
@@ -125,6 +127,7 @@ public:
             ui_utils::get_widget_from_glade<Gtk::FileChooserButton>
                                                     (glade, "filechooserbutton") ;
         THROW_IF_FAIL (fcbutton) ;
+        fcbutton->set_show_hidden (true) ;
         fcbutton->signal_selection_changed ().connect (sigc::mem_fun
                 (*this, &Priv::on_file_selection_changed)) ;
 
@@ -198,6 +201,7 @@ RunProgramDialog::RunProgramDialog (const UString &a_root_path) :
 
 RunProgramDialog::~RunProgramDialog ()
 {
+    LOG_D ("destroyed", "destructor-domain") ;
 }
 
 UString
