@@ -23,18 +23,22 @@
  *See COPYRIGHT file copyright information.
  */
 #include <map>
+#include <glib/gi18n.h>
 #include <gtkmm/table.h>
 #include <gtkmm/label.h>
 #include <gtkmm/scrolledwindow.h>
 #include <gtksourceviewmm/sourcemarker.h>
+#include <gtksourceviewmm/sourceiter.h>
 #include "nmv-exception.h"
 #include "nmv-source-editor.h"
 #include "nmv-ustring.h"
 #include "nmv-sequence.h"
 
 using namespace std ;
-using namespace nemiver::common ;
-using gtksourceview::SourceMarker ;
+using namespace nemiver::common;
+using gtksourceview::SourceMarker;
+using gtksourceview::SourceIter;
+using gtksourceview::SearchFlags;
 
 namespace nemiver {
 
@@ -196,10 +200,10 @@ struct SourceEditor::Priv {
         if (source_view && source_view->get_buffer ()) {
             line_count = source_view->get_buffer ()->get_line_count () ;
         }
-        line_col_label->set_text
-            (UString ("line: ") + UString::from_int (current_line)
-             + UString (", column: " + UString::from_int (current_column))
-             + UString (", lines: ") + UString::from_int (line_count)) ;
+        UString message;
+        message.printf (_("Line: %i, Column: %i, Lines: %i"),
+                    current_line, current_column, line_count) ;
+        line_col_label->set_text (message);
     }
 
     gint get_column_from_iter (const Gtk::TextBuffer::iterator &a_iter)
@@ -428,11 +432,10 @@ struct ScrollToLine {
 
     ScrollToLine () :
         m_line (0),
-        m_source_view (NULL)
+        m_source_view (0)
     {}
 
-    ScrollToLine (SourceView *a_source_view,
-                  int a_line) :
+    ScrollToLine (SourceView *a_source_view, int a_line) :
         m_line (a_line),
         m_source_view (a_source_view)
     {
@@ -441,8 +444,7 @@ struct ScrollToLine {
     bool do_scroll ()
     {
         if (!m_source_view) {return false;}
-        Gtk::TextIter iter =
-            m_source_view->get_buffer ()->get_iter_at_line (m_line) ;
+        Gtk::TextIter iter = m_source_view->get_buffer ()->get_iter_at_line (m_line) ;
         if (!iter) {return false;}
         m_source_view->scroll_to (iter, 0.1) ;
         return false ;
@@ -459,6 +461,20 @@ SourceEditor::scroll_to_line (int a_line)
                                                  &ScrollToLine::do_scroll)) ;
 }
 
+void
+SourceEditor::scroll_to_iter (Gtk::TextIter &a_iter)
+{
+    if (!a_iter) {
+        LOG_DD ("iter points at end of buffer") ;
+        return ;
+    }
+    static ScrollToLine s_scroll_functor ;
+    s_scroll_functor.m_line = a_iter.get_line ();
+    s_scroll_functor.m_source_view = m_priv->source_view ;
+    Glib::signal_idle ().connect (sigc::mem_fun (s_scroll_functor,
+                                                 &ScrollToLine::do_scroll)) ;
+}
+
 void
 SourceEditor::set_path (const UString &a_path)
 {
@@ -480,6 +496,15 @@ SourceEditor::get_file_name (UString &a_file_name)
     a_file_name = Glib::locale_to_utf8 (path) ;
 }
 
+bool
+is_word_delimiter (gunichar a_char)
+{
+    if (!isalnum (a_char) && a_char != '_') {
+        return true ;
+    }
+    return false ;
+}
+
 bool
 SourceEditor::get_word_at_position (int a_x,
                                     int a_y,
@@ -501,17 +526,19 @@ SourceEditor::get_word_at_position (int a_x,
         return false ;
     }
 
-    //go find the first white space before clicked_at_iter
+    //go find the first white word delimiter before clicked_at_iter
     Gtk::TextBuffer::iterator cur_iter = clicked_at_iter;
     if (!cur_iter) {return false;}
 
-    while (cur_iter.backward_char () && !isspace (cur_iter.get_char ())) {}
+    while (cur_iter.backward_char ()
+           && !is_word_delimiter (cur_iter.get_char ())) {}
     THROW_IF_FAIL (cur_iter.forward_char ()) ;
     Gtk::TextBuffer::iterator start_word_iter = cur_iter ;
 
-    //go find the first white space after clicked_at_iter
+    //go find the first word delimiter after clicked_at_iter
     cur_iter = clicked_at_iter ;
-    while (cur_iter.forward_char () && !isspace (cur_iter.get_char ())) {}
+    while (cur_iter.forward_char ()
+           && !is_word_delimiter (cur_iter.get_char ())) {}
     Gtk::TextBuffer::iterator end_word_iter = cur_iter ;
 
     UString var_name = start_word_iter.get_slice (end_word_iter);
@@ -538,6 +565,88 @@ SourceEditor::get_word_at_position (int a_x,
     return true ;
 }
 
+bool
+SourceEditor::do_search (const UString &a_str,
+                         Gtk::TextIter &a_start,
+                         Gtk::TextIter &a_end,
+                         bool a_match_case,
+                         bool a_match_entire_word,
+                         bool a_search_backwards,
+                         bool a_clear_selection)
+{
+    Glib::RefPtr<SourceBuffer> source_buffer = source_view ().get_source_buffer () ;
+    THROW_IF_FAIL (source_buffer) ;
+
+    if (a_clear_selection) {
+        source_buffer->select_range (source_buffer->end (),
+                                     source_buffer->end ()) ;
+    }
+
+    SourceIter search_iter, limit ;
+    if (a_search_backwards) {
+        search_iter = source_buffer->end () ;
+        search_iter-- ;
+        limit = source_buffer->begin () ;
+    } else {
+        search_iter = source_buffer->begin () ;
+        limit = source_buffer->end () ;
+        limit-- ;
+    }
+
+    Gtk::TextIter start, end ;
+    if (source_buffer->get_selection_bounds (start, end)) {
+        if (a_search_backwards) {
+            search_iter = start ;
+        } else {
+            search_iter = end ;
+        }
+    }
+
+    //*********************
+    //build search flags
+    //**********************
+    namespace gsv=gtksourceview ;
+    gsv::SearchFlags search_flags = gsv::SEARCH_TEXT_ONLY ;
+    if (!a_match_case) {
+        search_flags |= gsv::SEARCH_CASE_INSENSITIVE ;
+    }
+
+    bool found=false ;
+    if (a_search_backwards) {
+        if (search_iter.backward_search (a_str, search_flags,
+                                         a_start, a_end, limit)) {
+            found = true ;
+        }
+    } else {
+        if (search_iter.forward_search (a_str, search_flags,
+                    a_start, a_end, limit)) {
+            found = true ;
+        }
+    }
+
+    if (found && a_match_entire_word) {
+        Gtk::TextIter iter = a_start ;
+        if (iter.backward_char ()) {
+            if (!is_word_delimiter (*iter)) {
+                found = false ;
+            }
+        }
+        if (found) {
+            iter = a_end ;
+            if (!is_word_delimiter (*iter)) {
+                found = false;
+            }
+        }
+    }
+
+    if (found) {
+        source_buffer->select_range (a_start, a_end) ;
+        scroll_to_iter (a_start) ;
+        return true ;
+    }
+    return false ;
+}
+
 sigc::signal<void, int>&
 SourceEditor::marker_region_got_clicked_signal () const
 {
