@@ -23,9 +23,10 @@
  */
 
 #include <vector>
+#include <iostream>
 #include <glib/gi18n.h>
 #include <gtkmm/aboutdialog.h>
-//#include "nmv-env.h"
+#include <gtkmm/icontheme.h>
 #include "nmv-exception.h"
 #include "nmv-plugin.h"
 #include "nmv-ui-utils.h"
@@ -116,7 +117,6 @@ private:
     {
         WorkbenchStaticInit::do_init ();
     }
-    void shut_down () ;
     bool on_delete_event (GdkEventAny* event) ;
 
 public:
@@ -124,11 +124,13 @@ public:
     virtual ~Workbench () ;
     void get_info (Info &a_info) const ;
     void do_init (Gtk::Main &a_main) ;
+    void shut_down () ;
     Glib::RefPtr<Gtk::ActionGroup> get_default_action_group () ;
     Glib::RefPtr<Gtk::ActionGroup> get_debugger_ready_action_group ();
     Gtk::Widget& get_menubar ();
     Gtk::Notebook& get_toolbar_container ();
     Gtk::Window& get_root_window () ;
+    void set_title_extension (const UString &a_str) ;
     Glib::RefPtr<Gtk::UIManager>& get_ui_manager ()  ;
     IPerspective* get_perspective (const UString &a_name) ;
     IConfMgr& get_configuration_manager ()  ;
@@ -153,6 +155,7 @@ struct Workbench::Priv {
     map<UString, UString> properties ;
     IConfMgrSafePtr conf_mgr ;
     sigc::signal<void> shutting_down_signal ;
+    UString base_title;
 
     Priv () :
         initialized (false),
@@ -244,6 +247,20 @@ Workbench::on_about_menu_item_action ()
         "Boston, MA  02111-1307  USA\n";
     dialog.set_license(license);
 
+    // Translators: change this to your name, separate multiple names with \n
+    dialog.set_translator_credits(_("translator-credits"));
+
+    Glib::RefPtr<Gtk::IconTheme> theme = Gtk::IconTheme::get_default();
+    if (theme->has_icon("nemiver")) {
+        Glib::RefPtr<Gdk::Pixbuf> icon = theme->load_icon("nemiver", 128,
+                Gtk::ICON_LOOKUP_USE_BUILTIN);
+        dialog.set_logo(icon);
+    }
+
+    vector<Glib::ustring> artists;
+    artists.push_back("Steven Brown <swjb@interchange.ubc.ca>");
+    dialog.set_artists(artists);
+
     dialog.run ();
 
     NEMIVER_CATCH
@@ -292,6 +309,16 @@ Workbench::do_init (Gtk::Main &a_main)
 
     m_priv->main = &a_main ;
 
+    // set the icon that will be used by all workbench windows that don't
+    // explicitly call set_icon() (must be set before the root window is
+    // constructed)
+    Glib::RefPtr<Gtk::IconTheme> theme = Gtk::IconTheme::get_default();
+    if (theme->has_icon("nemiver")) {
+        Glib::RefPtr<Gdk::Pixbuf> icon = theme->load_icon("nemiver", 16,
+                Gtk::ICON_LOOKUP_USE_BUILTIN);
+        m_priv->root_window->set_default_icon(icon);
+    }
+
     init_glade () ;
     init_window () ;
     init_actions () ;
@@ -395,6 +422,16 @@ Workbench::get_root_window ()
     return *m_priv->root_window ;
 }
 
+void
+Workbench::set_title_extension (const UString &a_str)
+{
+    if (a_str.empty ()) {
+        get_root_window ().set_title (m_priv->base_title);
+    } else {
+        get_root_window ().set_title (a_str + " - " + m_priv->base_title);
+    }
+}
+
 Glib::RefPtr<Gtk::UIManager>&
 Workbench::get_ui_manager ()
 {
@@ -470,6 +507,12 @@ Workbench::init_glade ()
     m_priv->root_window.reset
            (ui_utils::get_widget_from_glade<Gtk::Window> (m_priv->glade,
                                                           "workbench"));
+    THROW_IF_FAIL (m_priv->root_window) ;
+    // get the title of the root window as specified in the glade file and save
+    // it so that later we can add state-specific extensions to this base title
+    // if needed
+    m_priv->base_title = m_priv->root_window->get_title ();
+
    // m_priv->root_window->property_allow_shrink ().set_value (true) ;
     m_priv->root_window->hide () ;
 }
